﻿// Copyright (c) AlphaSierraPapa for the SharpDevelop Team (for details please see \doc\copyright.txt)
// This code is distributed under the GNU LGPL (for details please see \doc\license.txt)

using System;
using Microsoft.Win32;

namespace ICSharpCode.SharpDevelop
{
	public class DotnetDetection
   {
		public static bool IsDotnet35SP1Installed()
		{
			using (var key = Registry.LocalMachine.OpenSubKey(@"SOFTWARE\Microsoft\NET Framework Setup\NDP\v3.5")) {
				return key != null && (key.GetValue("SP") as int?) >= 1;
			}
		}

      public static bool IsDotnet40Installed()
      {
         return true; // required for SD to run
      }

      //change the way to detect .NET Framework version 4.5 or later
      //please refer to https://docs.microsoft.com/en-us/dotnet/framework/migration-guide/how-to-determine-which-versions-are-installed

      const String subkey = @"SOFTWARE\Microsoft\NET Framework Setup\NDP\v4\Full\";
		
		public static bool IsDotnet45Installed()
		{
         int releasekey = 0;
         Microsoft.Win32.RegistryKey ndpKey = Microsoft.Win32.RegistryKey.OpenBaseKey(RegistryHive.LocalMachine, RegistryView.Registry32).OpenSubKey(subkey);
         if ((ndpKey != null) && (ndpKey.GetValue("Release") != null))
         {
            releasekey = (int)ndpKey.GetValue("Release");
         }

         return releasekey >= 378389;
      }
      public static bool IsDotnet47Installed()
      {
         int releasekey = 0;
         Microsoft.Win32.RegistryKey ndpKey = Microsoft.Win32.RegistryKey.OpenBaseKey(RegistryHive.LocalMachine, RegistryView.Registry32).OpenSubKey(subkey);
         if ((ndpKey != null) && (ndpKey.GetValue("Release") != null))
         {
            releasekey = (int)ndpKey.GetValue("Release");
         }

         return releasekey >= 460798;
      }
      public static bool IsDotnet471Installed()
      {
         int releasekey = 0;
         Microsoft.Win32.RegistryKey ndpKey = Microsoft.Win32.RegistryKey.OpenBaseKey(RegistryHive.LocalMachine, RegistryView.Registry32).OpenSubKey(subkey);
         if ((ndpKey != null) && (ndpKey.GetValue("Release") != null))
         {
            releasekey = (int)ndpKey.GetValue("Release");
         }

         return releasekey >= 461308;
      }
      public static bool IsDotnet472Installed()
      {
         int releasekey = 0;
         Microsoft.Win32.RegistryKey ndpKey = Microsoft.Win32.RegistryKey.OpenBaseKey(RegistryHive.LocalMachine, RegistryView.Registry32).OpenSubKey(subkey);
         if ((ndpKey != null) && (ndpKey.GetValue("Release") != null))
         {
            releasekey = (int)ndpKey.GetValue("Release");
         }

         return releasekey >= 461808;
      }
      public static bool IsDotnet48Installed()
      {
         int releasekey = 0;
         Microsoft.Win32.RegistryKey ndpKey = Microsoft.Win32.RegistryKey.OpenBaseKey(RegistryHive.LocalMachine, RegistryView.Registry32).OpenSubKey(subkey);
         if ((ndpKey != null) && (ndpKey.GetValue("Release") != null))
         {
            releasekey = (int)ndpKey.GetValue("Release");
         }

         return releasekey >= 528040;
      }
   }
}
